pm4py.evaluation.simplicity package
===================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   pm4py.evaluation.simplicity.variants

Submodules
----------

pm4py.evaluation.simplicity.evaluator module
--------------------------------------------

.. automodule:: pm4py.evaluation.simplicity.evaluator
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: pm4py.evaluation.simplicity
   :members:
   :undoc-members:
   :show-inheritance:
